#
# spec file for package OpenCSD
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Disable doc as graphviz does not include PNG support
%bcond_with build_html_doc

%define libnum  1
Name:           OpenCSD
Version:        1.5.1
Release:        1.5
Summary:        CoreSight Trace Decode library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/Linaro/OpenCSD
Source0:        https://github.com/Linaro/OpenCSD/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
%if %{with build_html_doc}
BuildRequires:  doxygen
BuildRequires:  graphviz
%endif

%description
OpenCSD is an Arm CoreSight Trace Decode library.

%package -n libopencsd%{libnum}
Summary:        C++ API for the CoreSight Trace Decode library
Group:          System/Libraries

%description -n libopencsd%{libnum}
C++ API for the OpenCSD library.

%package -n libopencsd_c_api%{libnum}
Summary:        C API for the CoreSight Trace Decode library
Group:          System/Libraries

%description -n libopencsd_c_api%{libnum}
C API for the OpenCSD library.

%package devel
Summary:        Headers for OpenCSD, a CoreSight Trace Decode library
Group:          Development/Libraries/C and C++
Requires:       libopencsd%{libnum} = %{version}
Requires:       libopencsd_c_api%{libnum} = %{version}

%description devel
Header files and libraries for C and C++ development with OpenCSD.

%package doc
Summary:        Documentation for the OpenCSD API
Group:          Documentation/Other
BuildArch:      noarch

%description doc
OpenCSD is an Arm CoreSight Trace Decode library.

%prep
%autosetup

%build
%make_build -C decoder/build/linux DISABLE_STATIC=1 \
%if %{with build_html_doc}
docs
%endif

%install
%make_install -C decoder/build/linux DISABLE_STATIC=1 LIB_PATH=%{_lib}
# Install man page
mkdir -p %{buildroot}/usr/share/man/man1/
%make_install -C decoder/build/linux DISABLE_STATIC=1 LIB_PATH=%{_lib} install_man

%post	-n libopencsd%{libnum} -p /sbin/ldconfig

%postun	-n libopencsd%{libnum} -p /sbin/ldconfig

%post	-n libopencsd_c_api%{libnum} -p /sbin/ldconfig

%postun	-n libopencsd_c_api%{libnum} -p /sbin/ldconfig

%files
%{_bindir}/trc_pkt_lister

%files -n libopencsd%{libnum}
%license LICENSE
%{_libdir}/libopencsd.so.%{version}
%{_libdir}/libopencsd.so.%{libnum}

%files -n libopencsd_c_api%{libnum}
%{_libdir}/libopencsd_c_api.so.%{version}
%{_libdir}/libopencsd_c_api.so.%{libnum}

%files devel
%{_libdir}/libopencsd.so
%{_libdir}/libopencsd_c_api.so
%{_includedir}/opencsd

%files doc
%doc HOWTO.md README.md TODO
%if %{with build_html_doc}
%doc decoder/docs/html/*.html
%endif
%doc decoder/docs/*.md
%_mandir/*/*

%changelog
* Tue Mar  5 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update 1.5.1:
  * Update: ETE: Add support for Arch 9.5 FEAT_PAUTH_LR.
  Add new instructions to disassembler to recognise RETASPPC
  variants as indirect branches. Adds new test snapshots.
* Sun Jan 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.2:
  * Decoder memory access - add debug features and cacheing to
    improve performance of decode.
    Caching controllable by API or environment variables.
  * Decode debug options to control potential runaway debug when
    incorrect memory images input to decoder.
    a) aarch64 instruction check for invalid instruction opcode.
    (any opcode with 0x0000 as top 16 bits).
    b) optional instruction range maximum run limit.
  * Memory spaces: ensure that decoder memory requests are
    correctly labelled with Realm and root characteristics when
    appropriate.
  * M class tail chained interrupts now correctly handled.
  * STM: - fix master and channel ID initialisation
  * Test: update README.md and perf-test-script.base for new paths
    (github issue #60 from yuxy-c)
  * build: Fix GCC version dir handling for versions of GCC > 9.
* Tue Sep 12 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to 1.4.1:
  * Test: Update test program trc_pkt_lister with option to have
    no logging output - final stats only.
  * Bugfix: ETM4x: ETE: Fix memory leak / use after free
    (github issues #53, #58 from yabinc)
  * Bugfix: C-API: Fix memory leak with output sink object.
    (github issue #55)
* Wed Mar 22 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to 1.4.0:
  * Update: ETE: Add support for Arch v9.4 FEAT_ITE. ETE v1p3,
    sw trace instrumentation. Adds in new generic output packet
    type: OCSD_GEN_TRC_ELEM_INSTRUMENTATION.
  * Bugfix: Fix memory leak in mispredict handling (github issue
    [#52] from yabinc)
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.3:
  * Update: Add test program for Coresight Frame Demux code
  * Bugfix: PTM: Fix incorrect extraction of Waypoint Address packet
  * Bugfix: Frame Demux: Fix HSYNC, FSYNC and 4xFSYNC handling that
    was causing out-of-bounds reads on invalid data input.
  * Fixed error handling for incorrect number of FSYNC packets in 4xFSYNC
    frame reset code that was not triggering an error and allowing fun
    with mis-aligned input data.
  * Bugfix: Fix silent failure if incorrect config flags set when setting up
    frame demux modes.
* Mon Sep 12 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.3.2:
  - Bugfix: ETM4x / ETE - 64 bit timestamp value - MS bit
    incorrectly masked to 1b0 during extraction from packet.
* Wed Aug  3 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.3.1:
  - Bugfix: Add header file in snapshot parser - fix build for
    certain libc++ libs (github issue #43 from manojgupta)
  - Bugfix: Fix typo in comment (github issue #42 from nothatDinger)
* Tue Apr  5 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.3.0:
  - Now supports ETE v1.2 instruction trace - packet processing
    and packet decode
  - Admin: Dev versions now have patch versions at least +100
    from root public version
  - Update: Add support for conditional branch (BC.cond)
    introduced for v8.8 / v9.3 architecture.
  - Update: ETE: Add support for NSE bit - security state bit
    defining Root / Realm states in FEAT_RME.
- Changes from 1.2.1:
  - Bugfix: ETM4x / ETE - output of context elements to client
    can in some circumstances be delayed until after subsequent
    atoms have been processed leading to incorrect memory decode
    access via the client callbacks. Fixed to flush context
    elements immediately they are committed.
* Wed Nov  3 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 1.2.0
  - __Bugfix__: Fix include and install for ETE decoder headers.
  - __Update__: Add API for counting packet decode statistics, and Frame debmux statistics.
  - __Update__: Update test scripts to allow additional command line options to be passed.
  - __Bugfix__: Fix various build warnings.
  - __Bugfix__: Remove unused variable (github issue #38 from Yi Kong)
  - __Bugfix__: Remove noisy printf (James Clark)
  - __Bugfix__: Fix documentation issues (github issues #39 & #40 from rbresalier)
* Thu Jun 17 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.1.0:
  - __Update__: ETM v4.6 support.
  - __Update__: C-API - add API functions to get last error and convert error code to string.
  - __Bugfix__: ETMv4/ETE - fix loop problem in commit elements.
  - __Bugfix__: ETMv4/ETE - make error handling consistent.
  - __Bugfix__: Add Pull request #36 from github (Ross Burton)
  - __Bugfix__: Add Pull request #37 from github (Ian Rogers)
* Fri Jan 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.0.0:
  - __New Decode Protocol__: Support added for the ETE protocol, used by ARM PEs that implement the FEAT_ETE
    feature. Supports new architectural features in this trace, including FEAT_TME.
  - __Update__: Output Elememts: New protocol defines two new output elements.
  - __Update__: Add support for WFIT / WFET instructions traced as P0 elements.
  - __Update__: Architecture versioning. Arch v8 + PEs may add features in a flexible manner, and ARM also
    declares future features ahead of architecture versions to allow support to be added.
    APIs requiring an architecture version can now use ARCH_AA64 to declare a version of v8.3 +
    additional features. This relaxes the strict versionnig rules that the decoder uses when
    looking for Opcodes as trace waypoints.
  - __Update__: docs: Add linux 'man' file and installation.
  - __Bugfix__: build: Fix clean install, and remove static lib build test from main makefile to
    dev makefile only. (github issue #33)
- Package man page
* Thu Nov 19 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.14.4:
  * __Update__: makefile: Add DESTDIR to install targets.
    (github issue #30)
  * __Update__: tests: add script to run single test only.
  * __Update__: docs: update to location of ARM coresight driver
    backports directory.
  * __Bugfix__: ETMv3: Fix missing comma in string list.
    (github issue #31)
  * __Bugfix__: makefile: tests: Fix build race problem
    (github issue #32)
  * __Bugfix__: tests: fix ignore tpiu command line options
    (github issue #28)
  Changes from 0.14.3:
  * __Update__: Fix makefile to be compliant with RPM base distros.
    (github issue #26, submitted by jlinton)
  * __Update__: Add section to autofdo document.
  * __Bugfix__: STM: fix bug that was missing ASYNC packets.
    (github issue #27, reported by subhasish Karmakar)
* Thu Jun 18 2020 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups, grammatically incorrect descriptions, and
  upgrade the boilerplate summary of openscd-devel.
* Thu Jun 18 2020 Martin Pluskal <mpluskal@suse.com>
- Rename spec file to match upstream project name
- Small packaging cleanups
* Wed Jun 17 2020 Mian Yousaf Kaukab <yousaf.kaukab@suse.com>
- Package API documentation
* Wed Jun 17 2020 Mian Yousaf Kaukab <yousaf.kaukab@suse.com>
- New SUSE package for opencsd library v0.14.2
